﻿/*
-------------------------------Copyright----------------------------
 SuperMap iDesktop 7C sample code
 Copyright: SuperMap Software Co., Ltd.
------------------------------------------------------------------

------------------------------SuperMap iDesktop 7C Sample Description----------------------------

1. Introduction：How to load customized working environment before starting the program.
2. Scene：When you start the program, the login window pops up. You can use admin or viwer to login. admin will load the whole default working environment; viewer will filter some advanced plugins.
3. Data: No       
4. Key files, types and members: 
      Application Type
      WorkEnvironmentManager Type
      WorkEnvironmentManager.Item Property
      PluginManager.PluginLoading Event
      PluginLoadingEventArgs.Cancel Property

5. Steps:
   (1) Start SuperMap.Desktop.Samples.CustomStartUp.exe;
   (2) Enter the username and password;
   (3) viewer will load basic plugins
   (4) admin will load all plugins.

---------------------------------------------------------------------------------------------
*/

using System;
using System.Collections.Generic;
using System.Windows.Forms;
using Application = SuperMap.Desktop.Application;

namespace SuperMap.Desktop.Samples
{
    static class CustomStartUp
    {
        /// <summary>
        ///  Main entry point for your application
        /// </summary>
        [STAThread]
        static void Main()
        {
            try
            {
                System.Windows.Forms.Application.EnableVisualStyles();
                System.Windows.Forms.Application.SetCompatibleTextRenderingDefault(false);
                Application.ActiveApplication = new Application();
                Application currentApplication = Application.ActiveApplication;
                
                //Open the login window
                FormAccess form = new FormAccess();

                //If the login is successful, you can load different plugins according to the user
                if (form.ShowDialog()==DialogResult.OK)
                {

                    //Initialize the program and run it
                    currentApplication.Initialize();
                    //working environment should be invoked after the method "Initialize()"
                    //If it is the admin user, it will load whole Default working environment
                    if (form.UserName == "admin")
                    {
                        //Set the loading environment
                        currentApplication.WorkEnvironmentManager.ActiveWorkEnvironmentName = "Default";
                    }
                    //If it is the viewer, it will filter advanced plugins in Default working environment
                    else if(form.UserName=="viewer")
                    {
                        currentApplication.WorkEnvironmentManager.ActiveWorkEnvironmentName = "Default";
                        //Register the event for loading plugins
                        currentApplication.PluginManager.PluginLoading += new PluginLoadingEventHandler(PluginManager_PluginLoading);
                    }
                    currentApplication.Run();
                    currentApplication.Exit();
                }
                else
                {
                    return;
                }
            }
            catch (Exception)
            {

            }
        }

        static void PluginManager_PluginLoading(object sender, PluginLoadingEventArgs e)
        {
            try
            {
                //获取插件信息，判断如果是高级插件，则不加载
                String currentPluginName = e.Plugin.PluginInfo.Name;
                if (currentPluginName == "ChartModule"
                    || currentPluginName == "HydrologyAnalyst"
                    || currentPluginName == "LinearReferencing"
                    || currentPluginName == "SpatialAnalyst")
                {
                    e.Cancel = true;
                }
            }
            catch (Exception ex)
            {
                Application.ActiveApplication.Output.Output(ex.Message, InfoType.Exception);
                Application.ActiveApplication.Output.Output(ex.StackTrace, InfoType.Exception);
            }
        }
    }
}
